# Description

> _Briefly describe the purpose and content of this merge request._
> _E.g. "Add structure generation constraints", or "Fix bug in energy parsing"._

# Checklist

Mark with `x` when complete, or `~` if not applicable.

- [ ] [I have read and followed the **RAFFLE's contribution guidelines.**](https://github.com/ExeQuantCode/RAFFLE/blob/main/CONTRIBUTING.md)
- [ ] **Code is commented** appropriately, and API docstrings follow NumPy or FORD style.
- [ ] **Read*the*Docs** documentation is added/updated (if applicable).
- [ ] **Unit tests** are added/updated (if applicable).
- [ ] **Linked issue** is resolved with a `closes #XXXX` reference (if applicable).
